pub struct DataHash {
pub exclusions: Option<Vec<HashRange>>,
pub name: Option<String>,
pub alg: Option<String>,
pub hash: Vec<u8>,
pub pad: Vec<u8>,
pub pad2: Option<ByteBuf>,
pub url: Option<UriT>,
pub path: PathBuf,
}Expand description
Helper class to create DataHash assertion
Fields
exclusions: Option<Vec<HashRange>>name: Option<String>alg: Option<String>hash: Vec<u8>pad: Vec<u8>pad2: Option<ByteBuf>url: Option<UriT>path: PathBufImplementations
Sourceimpl DataHash
impl DataHash
pub const LABEL: &'static str = labels::DATA_HASH
pub fn add_exclusion(&mut self, exclusion: HashRange)
pub fn set_hash(&mut self, hash: Vec<u8>)
pub fn add_padding(&mut self, padding: Vec<u8>)
Sourcepub fn is_remote_hash(&self) -> bool
pub fn is_remote_hash(&self) -> bool
Checks if this is a remote hash
Sourcepub fn gen_hash(&mut self, asset_path: &Path) -> Result<()>
pub fn gen_hash(&mut self, asset_path: &Path) -> Result<()>
generate the hash value for the Asset using the range from the DataHash
Sourcepub fn gen_hash_from_stream<R>(&mut self, stream: &mut R) -> Result<()>
pub fn gen_hash_from_stream<R>(&mut self, stream: &mut R) -> Result<()>
generate the hash value for the Asset stream using the range from the DataHash
pub fn pad_to_size(&mut self, desired_size: usize) -> Result<()>
Sourcepub fn hash_from_stream<R>(&mut self, stream: &mut R) -> Result<Vec<u8>>
pub fn hash_from_stream<R>(&mut self, stream: &mut R) -> Result<Vec<u8>>
generate the asset hash from a stream using the constructed start and length values
pub fn verify_in_memory_hash( &self, data: &[u8], alg: Option<&str>, ) -> Result<()>
Sourcepub fn verify_hash(&self, asset_path: &Path, alg: Option<&str>) -> Result<()>
pub fn verify_hash(&self, asset_path: &Path, alg: Option<&str>) -> Result<()>
Used to verify a DataHash against an asset.
pub fn verify_stream_hash( &self, reader: &mut dyn CAIRead, alg: Option<&str>, ) -> Result<()>
Sourcepub fn from_assertion(assertion: &Assertion) -> Result<Self>
pub fn from_assertion(assertion: &Assertion) -> Result<Self>
Create a new instance from Assertion