Error

Enum Error 

#[non_exhaustive]
pub enum Error {
Show 97 variants ClaimMissing { label: String, }, AssertionMissing { url: String, }, AssertionEncoding(String), AssertionDecoding(AssertionDecodeError), AssertionInvalidRedaction, AssertionRedactionNotFound, AssertionSpecificError(String), BadParam(String), OperationCancelled, ValidationRule(String), NotImplemented(String), ClaimEncoding, ClaimDecoding(String), ClaimUnsigned, ClaimMissingSignatureBox, ClaimVersion, ClaimInvalidContent, ClaimMissingHardBinding, ClaimMultipleHardBinding, ClaimSelfRedact, ClaimDisallowedRedaction, UpdateManifestInvalid, TooManyManifestStores, TooManyAssertions { max: usize, }, CoseSignatureAlgorithmNotSupported, CoseX5ChainMissing, CoseInvalidCert, CoseSignature, CoseVerifier, CoseTimeStampGeneration, CoseSigboxTooSmall, CoseNoCerts, JumbfCreationError, ThreadReceiveError, JumbfNotFound, JumbfBoxNotFound, RemoteManifestFetch(String), RemoteManifestUrl(String), FailedToRemoteSign, NotFound, UnsupportedType, UnsupportedThumbnailFormat(String), MissingSignerSettings, MissingAutoCreatedActionSourceType, EmbeddingError, IngredientNotFound, FileNotFound(String), ResourceNotFound(String), XmpReadError(String), XmpWriteError(String), XmpNotSupported, ProvenanceMissing, HashMismatch(String), CyclicIngredients { claim_label_path: Vec<String>, }, ClaimVerification(String), PdfReadError, InvalidClaim(InvalidClaimError), InvalidAsset(String), JumbfParseError(JumbfParseError), VerifiableCredentialInvalid, InvalidEcdsaSignature, MissingDataBox, XmlWriteError, UnknownAlgorithm, InvalidSigningKey, Utf8Error(Utf8Error), HttpError(Error), HttpResolverError(HttpResolverError), TryFromIntError(TryFromIntError), IoError(Error), JsonError(Error), ImageError(ImageError), CborError(Error), TomlSerializationError(Error), OtherError(Box<dyn Error + Send + Sync + 'static>), PrereleaseError, VersionCompatibility(String), InsufficientMemory, TimeStampError(TimeStampError), RawSignatureValidationError(RawSignatureValidationError), RawSignerError(RawSignerError), CertificateProfileError(CertificateProfileError), CertificateTrustError(CertificateTrustError), InvalidCertificateError(InvalidCertificateError), InternalError(String), C2PAValidation(String), InvalidManifest(ValidationResults), BmffError(BmffError), GifError(GifError), JpegError(JpegError), Mp3Error(Mp3Error), FlacError(FlacError), PdfError(PdfError), PngError(PngError), RiffError(RiffError), SvgError(SvgError), TiffError(TiffError),
}
Error enumerates errors returned by most C2PA toolkit operations.

Stability

Prior to the 1.0 release of this SDK, this type is expected to undergo non-trivial refactoring: variants may be added, removed, renamed, or have their payloads reshaped between minor releases. The project’s deprecation policy is followed on a best-effort basis pre-1.0, and Error in particular is likely to see breaking changes ahead of 1.0 as the surface area is pared down. Downstream code matching on specific variants should expect churn until 1.0.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ClaimMissing

Could not find a claim with this label.

Fields

label: String


AssertionMissing

An assertion could not be found at the expected URL.

Fields



AssertionEncoding(String)

The attempt to serialize the assertion (typically to JSON or CBOR) failed.



AssertionDecoding(AssertionDecodeError)



AssertionInvalidRedaction



AssertionRedactionNotFound



AssertionSpecificError(String)



BadParam(String)



OperationCancelled

The operation was cancelled by a progress callback or cancellation token.



ValidationRule(String)



NotImplemented(String)



ClaimEncoding

The attempt to serialize the claim to CBOR failed.



ClaimDecoding(String)

The attempt to deserialize the claim from CBOR failed.



ClaimUnsigned



ClaimMissingSignatureBox



ClaimVersion



ClaimInvalidContent



ClaimMissingHardBinding



ClaimMultipleHardBinding



ClaimSelfRedact



ClaimDisallowedRedaction



UpdateManifestInvalid



TooManyManifestStores



TooManyAssertions

Fields

max: usize


CoseSignatureAlgorithmNotSupported

The COSE signature uses an algorithm that is not supported by this crate.



CoseX5ChainMissing

The COSE signature did not contain a signing certificate.



CoseInvalidCert



CoseSignature



CoseVerifier



CoseTimeStampGeneration

Unable to generate a trusted time stamp.



CoseSigboxTooSmall



CoseNoCerts



JumbfCreationError

Unable to generate valid JUMBF for a claim.



ThreadReceiveError



JumbfNotFound



JumbfBoxNotFound



RemoteManifestFetch(String)



RemoteManifestUrl(String)



FailedToRemoteSign



NotFound



UnsupportedType



UnsupportedThumbnailFormat(String)



MissingSignerSettings



MissingAutoCreatedActionSourceType



EmbeddingError



IngredientNotFound



FileNotFound(String)



ResourceNotFound(String)



XmpReadError(String)



XmpWriteError(String)



XmpNotSupported



ProvenanceMissing



HashMismatch(String)



CyclicIngredients

Fields

claim_label_path: Vec<String>


ClaimVerification(String)



PdfReadError



InvalidClaim(InvalidClaimError)



InvalidAsset(String)



JumbfParseError(JumbfParseError)



VerifiableCredentialInvalid



InvalidEcdsaSignature

Could not parse ECDSA signature. (Only appears when using WASM web crypto.)



MissingDataBox



XmlWriteError



UnknownAlgorithm



InvalidSigningKey



Utf8Error(Utf8Error)



HttpError(Error)



HttpResolverError(HttpResolverError)



TryFromIntError(TryFromIntError)



IoError(Error)



JsonError(Error)



ImageError(ImageError)

Available on crate feature add_thumbnails only.


CborError(Error)



TomlSerializationError(Error)



OtherError(Box<dyn Error + Send + Sync + 'static>)



PrereleaseError



VersionCompatibility(String)



InsufficientMemory



TimeStampError(TimeStampError)



RawSignatureValidationError(RawSignatureValidationError)



RawSignerError(RawSignerError)



CertificateProfileError(CertificateProfileError)



CertificateTrustError(CertificateTrustError)



InvalidCertificateError(InvalidCertificateError)



InternalError(String)

An unexpected internal error occured while requesting the time stamp response.



C2PAValidation(String)



InvalidManifest(ValidationResults)



BmffError(BmffError)



GifError(GifError)



JpegError(JpegError)



Mp3Error(Mp3Error)



FlacError(FlacError)



PdfError(PdfError)

Available on crate feature pdf only.


PngError(PngError)



RiffError(RiffError)



SvgError(SvgError)



TiffError(TiffError)