pub enum Relationship {
ParentOf,
ComponentOf,
InputTo,
}Expand description
The relationship of the ingredient to the current asset.
Variants
ParentOf
The current asset is derived from this ingredient.
ComponentOf
The current asset is a part of this ingredient.
InputTo
The ingredient was used as an input to a computational process to create or modify the asset.
Implementations